Object of class eq_dist with components r_gen and r_eq.
The function r_gen(n, mean) generates random deviates from a mixture of two gamma distributions with specified
mean, shape1, shape2, scale_ratio, and mix. The cumulative distribution function
is given by $$F(x) = p \Gamma(x; k_1, \theta_1) + (1 - p) \Gamma(x; k_2, \theta_2),$$ where \(\Gamma(x; k, \theta)\)
is the cumulative distribution function of a Gamma random variable with shape \(k\) and scale \(\theta\), and
the scale parameters are determined by the specified mean and scale_ratio.
The function r_eq(n, mean) generates random deviates from the equilibrium distribution corresponding
to the mixture of gamma distributions.