Calculates the log-likelihood of within-session PIR data
PIR_loglik(param, U, c, d)The value of the log-likelihood
vector of parameter values logit(prevalence), log(incidence)
a vector containing interval-level PIR data
the length of the active interval
the length of the recording interval
The vector U should only contain values of 1 or 0.
c must be a positive value. d must be some non-negative value. Setting
d equal to zero represents a PIR observation where no time was set aside for recording.
Daniel Swan <dswan@utexas.edu>